@@ -1,3 +1,7 @@
+//! Solver configuration.
+
+#![allow(missing_docs)]
+
 #[cfg(test)]
 #[path = "../../../tests/unit/extensions/solve/config_test.rs"]
 mod config_test;
@@ -11,17 +15,24 @@ use vrp_core::models::Problem;
 use vrp_core::solver::mutation::*;
 use vrp_core::solver::{Builder, Telemetry, TelemetryMode};
 
+/// An algorithm configuration.
 #[derive(Clone, Deserialize, Debug)]
 pub struct Config {
+    /// Specifies population configuration.
     population: Option<PopulationConfig>,
+    /// Specifies mutation operator configuration.
     mutation: Option<MutationConfig>,
+    /// Specifies algorithm termination configuration.
     termination: Option<TerminationConfig>,
+    /// Specifies telemetry configuration.
     telemetry: Option<TelemetryConfig>,
 }
 
+/// A mutation operator configuration.
 #[derive(Clone, Deserialize, Debug)]
 #[serde(tag = "type")]
 pub enum MutationConfig {
+    /// A ruin and recreate metaheuristic settings.
     #[serde(rename(deserialize = "ruin-recreate"))]
     RuinRecreate {
         /// Ruin methods.
@@ -31,6 +42,7 @@ pub enum MutationConfig {
     },
 }
 
+/// A ruin method configuration
 #[derive(Clone, Deserialize, Debug)]
 pub struct ConfigRuinGroup {
     methods: Vec<RuinMethod>,
@@ -41,16 +53,22 @@ pub struct ConfigRuinGroup {
 #[derive(Clone, Deserialize, Debug)]
 #[serde(tag = "type")]
 pub enum RuinMethod {
+    /// Adjusted string removal method.
     #[serde(rename(deserialize = "adjusted-string"))]
     AdjustedString { probability: f64, lmax: usize, cavg: usize, alpha: f64 },
+    /// Neighbour jobs method
     #[serde(rename(deserialize = "neighbour"))]
     Neighbour { probability: f64, min: usize, max: usize, threshold: f64 },
+    /// Random job removal method.
     #[serde(rename(deserialize = "random-job"))]
     RandomJob { probability: f64, min: usize, max: usize, threshold: f64 },
+    /// Random route removal method.
     #[serde(rename(deserialize = "random-route"))]
     RandomRoute { probability: f64, min: usize, max: usize, threshold: f64 },
+    /// Worst job removal method.
     #[serde(rename(deserialize = "worst-job"))]
     WorstJob { probability: f64, min: usize, max: usize, threshold: f64, skip: usize },
+    /// Clustered jobs removal method.
     #[serde(rename(deserialize = "cluster"))]
     Cluster { probability: f64, min: usize, max: usize, threshold: f64, cmin: usize, cmax: usize },
 }
@@ -59,14 +77,19 @@ pub enum RuinMethod {
 #[derive(Clone, Deserialize, Debug)]
 #[serde(tag = "type")]
 pub enum RecreateMethod {
+    /// Cheapest insertion method.
     #[serde(rename(deserialize = "cheapest"))]
     Cheapest { weight: usize },
+    /// Regret insertion method.
     #[serde(rename(deserialize = "regret"))]
     Regret { weight: usize, start: usize, end: usize },
     #[serde(rename(deserialize = "blinks"))]
+    /// Insertion with blinks method.
     Blinks { weight: usize },
     #[serde(rename(deserialize = "gaps"))]
+    /// Insertion with gaps method.
     Gaps { weight: usize, min: usize },
+    /// Nearest neighbour method.
     #[serde(rename(deserialize = "nearest"))]
     Nearest { weight: usize },
 }
@@ -78,7 +101,6 @@ pub struct PopulationConfig {
     initial_size: Option<usize>,
     population_size: Option<usize>,
     offspring_size: Option<usize>,
-    elite_size: Option<usize>,
 }
 
 #[derive(Clone, Deserialize, Debug)]
@@ -106,7 +128,7 @@ pub struct TelemetryConfig {
 pub struct LoggingConfig {
     /// Specifies whether logging is enabled. Default is false.
     enabled: bool,
-    /// Specifies how often best individual is tracked. Default is 100 (generations).
+    /// Specifies how often best individual is logged. Default is 100 (generations).
     log_best: Option<usize>,
     /// Specifies how often population is logged. Default is 1000 (generations).
     log_population: Option<usize>,
@@ -136,10 +158,6 @@ fn configure_from_population(mut builder: Builder, population_config: &Option<Po
             builder = builder.with_population_size(*population_size);
         }
 
-        if let Some(elite_size) = &config.elite_size {
-            builder = builder.with_elite_size(*elite_size);
-        }
-
         if let Some(offspring_size) = &config.offspring_size {
             builder = builder.with_offspring_size(*offspring_size);
         }
@@ -171,7 +189,7 @@ fn configure_from_termination(mut builder: Builder, termination_config: &Option<
     builder
 }
 
-fn create_recreate_method(method: &RecreateMethod) -> (Box<dyn Recreate>, usize) {
+fn create_recreate_method(method: &RecreateMethod) -> (Box<dyn Recreate + Send + Sync>, usize) {
     match method {
         RecreateMethod::Cheapest { weight } => (Box::new(RecreateWithCheapest::default()), *weight),
         RecreateMethod::Regret { weight, start, end } => (Box::new(RecreateWithRegret::new(*start, *end)), *weight),
@@ -185,7 +203,7 @@ fn create_ruin_group(problem: &Arc<Problem>, group: &ConfigRuinGroup) -> RuinGro
     (group.methods.iter().map(|r| create_ruin_method(problem, r)).collect(), group.weight)
 }
 
-fn create_ruin_method(problem: &Arc<Problem>, method: &RuinMethod) -> (Arc<dyn Ruin>, f64) {
+fn create_ruin_method(problem: &Arc<Problem>, method: &RuinMethod) -> (Arc<dyn Ruin + Send + Sync>, f64) {
     match method {
         RuinMethod::AdjustedString { probability, lmax, cavg, alpha } => {
             (Arc::new(AdjustedStringRemoval::new(*lmax, *cavg, *alpha)), *probability)
