@@ -15,12 +15,12 @@ mod cli {
     use super::commands::solve::{get_solve_app, run_solve};
     use crate::commands::check::{get_check_app, run_check};
     use crate::commands::generate::{get_generate_app, run_generate};
-    use clap::App;
+    use clap::{crate_version, App};
     use std::process;
 
     pub fn run_app() {
         let matches = App::new("Vehicle Routing Problem Solver")
-            .version("0.1")
+            .version(crate_version!())
             .author("Ilya Builuk <ilya.builuk@gmail.com>")
             .about("A command line interface to Vehicle Routing Problem solver")
             .subcommand(get_solve_app())
@@ -33,7 +33,7 @@ mod cli {
             ("solve", Some(solve_matches)) => run_solve(solve_matches),
             ("import", Some(import_matches)) => run_import(import_matches),
             ("check", Some(check_matches)) => run_check(check_matches),
-            ("generate", Some(check_matches)) => run_generate(check_matches),
+            ("generate", Some(generate_matches)) => run_generate(generate_matches),
             ("", None) => {
                 eprintln!("No subcommand was used. Use -h to print help information.");
                 process::exit(1);
